RTPI - Oxfordshire

Oxontime Links

- Oxontime Home
- Search Options
- News / Status
- SMS Service
- About Oxontime
- Coverage
- Instructions / Help
- Terms of Use
- Text Only

Contact Us

- contact@oxontime.com
- Oxontime RTI
  Oxfordshire County Council
  Speedwell House
  Speedwell Street
  Oxford OX1 1NE

# Search options

To find live departure information on bus services use the search options below and select your required bus stop.

SMS number | 69327523
Stop name | George Street B2 View on map
Refresh time | 29/03/2012 14:28:54
Stop messages | -The terminus for the inbound S1 is at stop B1 (west end of George St) -For the S2 & S3 go to Gloucester Green (bus station) -Stop closed - long term closure to allow demolition & rebuilding works -Please refer to notices posted at the stop

Message
No current departures for this stop.